@@ -1,10 +1,8 @@
 package Blosxom::Header;
 use strict;
 use warnings;
-use base 'Exporter';
 
-our $VERSION   = '0.01007';
-our @EXPORT_OK = qw(headers);
+our $VERSION   = '0.01008';
 
 sub new {
     my $class   = shift;
@@ -13,8 +11,6 @@ sub new {
     return bless { headers => $headers }, $class;
 }
 
-sub headers { __PACKAGE__->new(@_) }
-
 sub get {
     my $self    = shift;
     my $key     = _lc(shift);
@@ -46,7 +42,7 @@ sub set {
     my $value = shift;
 
     if ($key) {
-        $self->{headers}->{$key} = $value;
+        $self->{headers}{$key} = $value;
     }
 
     return;
@@ -58,7 +54,7 @@ sub exists {
 
     my $exists;
     if ($key) {
-        $exists = exists $self->{headers}->{$key};
+        $exists = exists $self->{headers}{$key};
     }
 
     return $exists;
@@ -86,11 +82,11 @@ Blosxom::Header - Missing interface to modify HTTP headers
 
 =head1 SYNOPSIS
 
-  use Blosxom::Header qw(headers);
+  use Blosxom::Header;
 
   my $headers = { -type => 'text/html' };
 
-  my $h = headers($headers);
+  my $h = Blosxom::Header->new($headers);
   my $value = $h->get($key);
   my $bool = $h->exists($key);
 
@@ -116,7 +112,7 @@ them.
 This module allows you to modify them in an object-oriented way.
 If loaded, you might write as follows:
 
-  my $h = headers($blosxom::header);
+  my $h = Blosxom::Header->new($blosxom::header);
   $h->set('Content-Type' => 'text/plain');
 
 =head2 METHODS
@@ -125,8 +121,6 @@ If loaded, you might write as follows:
 
 =item $h = Blosxom::Header->new($headers);
 
-=item $h = headers($headers);
-
 Creates a new Blosxom::Header object.
 The object holds a reference to the original given $headers argument.
 
@@ -152,12 +146,14 @@ Deletes the specified element from HTTP headers.
 
   # plugins/content_length
   package content_length;
-  use Blosxom::Header qw(headers);
+  use Blosxom::Header;
 
-  sub start { 1 }
+  sub start {
+      return $blosxom::static_or_dynamic eq 'dynamic' ? 1 : 0;
+  }
 
   sub last {
-      my $h = headers($blosxom::header);
+      my $h = Blosxom::Header->new($blosxom::header);
       $h->set('Content-Length' => length $blosxom::output);
   }
 
